==> percona-server_8.0.36-28.orig.tar.gz: percona-server-8.0.36-28/extra/libkmip/libkmip/src/CMakeFiles/kmip.dir/DependInfo.cmake <==
# The set of languages for which implicit dependencies are needed:
set(CMAKE_DEPENDS_LANGUAGES
  "C"
  )
# The set of files for implicit dependencies of each language:
set(CMAKE_DEPENDS_CHECK_C
  "/mnt/jenkins/workspace/ps8.0-autobuild-RELEASE/test/percona-server/extra/libkmip/libkmip/src/kmip.c" "/mnt/jenkins/workspace/ps8.0-autobuild-RELEASE/test/percona-server/extra/libkmip/libkmip/src/CMakeFiles/kmip.dir/kmip.c.o"
  "/mnt/jenkins/workspace/ps8.0-autobuild-RELEASE/test/percona-server/extra/libkmip/libkmip/src/kmip_bio.c" "/mnt/jenkins/workspace/ps8.0-autobuild-RELEASE/test/percona-server/extra/libkmip/libkmip/src/CMakeFiles/kmip.dir/kmip_bio.c.o"
  "/mnt/jenkins/workspace/ps8.0-autobuild-RELEASE/test/percona-server/extra/libkmip/libkmip/src/kmip_locate.c" "/mnt/jenkins/workspace/ps8.0-autobuild-RELEASE/test/percona-server/extra/libkmip/libkmip/src/CMakeFiles/kmip.dir/kmip_locate.c.o"
  "/mnt/jenkins/workspace/ps8.0-autobuild-RELEASE/test/percona-server/extra/libkmip/libkmip/src/kmip_memset.c" "/mnt/jenkins/workspace/ps8.0-autobuild-RELEASE/test/percona-server/extra/libkmip/libkmip/src/CMakeFiles/kmip.dir/kmip_memset.c.o"
  )
set(CMAKE_C_COMPILER_ID "GNU")

# Preprocessor definitions for this target.
set(CMAKE_TARGET_DEFINITIONS_C
  "BOOST_NO_CXX98_FUNCTION_BASE"
  "HAVE_CONFIG_H"
  "HAVE_TLSv13"
  "LZ4_DISABLE_DEPRECATE_WARNINGS"
  "_FILE_OFFSET_BITS=64"
  "_GNU_SOURCE"
  "_USE_MATH_DEFINES"
  "__STDC_FORMAT_MACROS"
  "__STDC_LIMIT_MACROS"
  )

# The include file search paths:
set(CMAKE_C_TARGET_INCLUDE_PATH
  "."
  "include"
  "extra/libkmip/libkmip/include"
  "extra/protobuf/protobuf-3.19.4/src"
  )

# Targets to which this target links.
set(CMAKE_TARGET_LINKED_INFO_FILES
  )

# Fortran module output directory.
set(CMAKE_Fortran_TARGET_MODULE_DIR "")

==> percona-server_8.0.41-32.orig.tar.gz: percona-server-8.0.41-32/extra/libkmip/libkmip/src/CMakeFiles/kmip.dir/DependInfo.cmake <==
# The set of languages for which implicit dependencies are needed:
set(CMAKE_DEPENDS_LANGUAGES
  "C"
  )
# The set of files for implicit dependencies of each language:
set(CMAKE_DEPENDS_CHECK_C
  "/mnt/jenkins/workspace/ps8.0-autobuild-RELEASE/test/percona-server/extra/libkmip/libkmip/src/kmip.c" "/mnt/jenkins/workspace/ps8.0-autobuild-RELEASE/test/percona-server/extra/libkmip/libkmip/src/CMakeFiles/kmip.dir/kmip.c.o"
  "/mnt/jenkins/workspace/ps8.0-autobuild-RELEASE/test/percona-server/extra/libkmip/libkmip/src/kmip_bio.c" "/mnt/jenkins/workspace/ps8.0-autobuild-RELEASE/test/percona-server/extra/libkmip/libkmip/src/CMakeFiles/kmip.dir/kmip_bio.c.o"
  "/mnt/jenkins/workspace/ps8.0-autobuild-RELEASE/test/percona-server/extra/libkmip/libkmip/src/kmip_locate.c" "/mnt/jenkins/workspace/ps8.0-autobuild-RELEASE/test/percona-server/extra/libkmip/libkmip/src/CMakeFiles/kmip.dir/kmip_locate.c.o"
  "/mnt/jenkins/workspace/ps8.0-autobuild-RELEASE/test/percona-server/extra/libkmip/libkmip/src/kmip_memset.c" "/mnt/jenkins/workspace/ps8.0-autobuild-RELEASE/test/percona-server/extra/libkmip/libkmip/src/CMakeFiles/kmip.dir/kmip_memset.c.o"
  )
set(CMAKE_C_COMPILER_ID "GNU")

# Preprocessor definitions for this target.
set(CMAKE_TARGET_DEFINITIONS_C
  "BOOST_NO_CXX98_FUNCTION_BASE"
  "HAVE_TLSv13"
  "LZ4_DISABLE_DEPRECATE_WARNINGS"
  "_FILE_OFFSET_BITS=64"
  "_GNU_SOURCE"
  "_USE_MATH_DEFINES"
  "__STDC_FORMAT_MACROS"
  "__STDC_LIMIT_MACROS"
  )

# The include file search paths:
set(CMAKE_C_TARGET_INCLUDE_PATH
  "."
  "include"
  "extra/libkmip/libkmip/include"
  "extra/protobuf/protobuf-24.4/src"
  )

# Targets to which this target links.
set(CMAKE_TARGET_LINKED_INFO_FILES
  )

# Fortran module output directory.
set(CMAKE_Fortran_TARGET_MODULE_DIR "")
